package domain;

import java.util.StringTokenizer;

public class Duration extends Clock {
	public Duration() {
		super(1, 0);
	}
	public Duration(int hour, int minute) throws BadHourException, BadMinuteException {
		if (hour < 0) throw new BadHourException(hour);
		h = hour;
		if (minute < 0 || minute >= MINUTES_PER_HOUR) throw new BadMinuteException(minute);
		m = minute;
	}
	public Duration(String s) throws BadHourException, BadMinuteException, BadFormatException {
		if (!s.matches("^[0-9]+h[0-5][0-9]$")) throw new BadFormatException(s);
		StringTokenizer st = new StringTokenizer(s, ":");
		h = Integer.parseInt(st.nextToken());
		if (h < 0) throw new BadHourException(h);
		m = Integer.parseInt(st.nextToken());
		if (m < 0 || m >= MINUTES_PER_HOUR) throw new BadMinuteException(m);
	}
	public void oneHourMore() {
		h++;
	}
	public void oneHourLess() throws NegativeDurationException {
		if (h < 1) throw new NegativeDurationException(this);
		h--;
	}
	public void oneMinuteLess() throws NegativeDurationException {
		m--;
		if (m < 0 ) {
			m = MINUTES_PER_HOUR - 1;
			oneHourLess();
		}
	}
	public String toString() {
		String s = "V1 ";
		s += h;
		s += "h";
		s += (m < 10) ? "0" : "";
		s += m;
		return s;
	}
}
